[Ocfs2-tools-commits] manish commits r580 - trunk/ocfs2console

svn-commits at oss.oracle.com svn-commits at oss.oracle.com
Tue Jan 25 20:05:10 CST 2005


Author: manish
Date: 2005-01-25 20:05:08 -0600 (Tue, 25 Jan 2005)
New Revision: 580

Modified:
   trunk/ocfs2console/about.py
   trunk/ocfs2console/browser.py
   trunk/ocfs2console/clconfig.py
   trunk/ocfs2console/format.py
   trunk/ocfs2console/general.py
   trunk/ocfs2console/guiutil.py
   trunk/ocfs2console/interface.py
   trunk/ocfs2console/menu.py
   trunk/ocfs2console/nodemap.py
   trunk/ocfs2console/ocfs2console.8.in
   trunk/ocfs2console/process.py
   trunk/ocfs2console/toolbar.py
Log:
More renaming to ocfs2console


Modified: trunk/ocfs2console/about.py
===================================================================
--- trunk/ocfs2console/browser.py	2005-01-26 01:33:38 UTC (rev 579)
+++ trunk/ocfs2console/browser.py	2005-01-26 02:05:08 UTC (rev 580)
@@ -1,4 +1,4 @@
-# OCFS2Tool - GUI frontend for OCFS2 management and debugging
+# OCFS2Console - GUI frontend for OCFS2 management and debugging
 # Copyright (C) 2002, 2005 Oracle.  All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify

Modified: trunk/ocfs2console/clconfig.py
===================================================================
--- trunk/ocfs2console/clconfig.py	2005-01-26 01:33:38 UTC (rev 579)
+++ trunk/ocfs2console/clconfig.py	2005-01-26 02:05:08 UTC (rev 580)
@@ -1,4 +1,4 @@
-# OCFS2Tool - GUI frontend for OCFS2 management and debugging
+# OCFS2Console - GUI frontend for OCFS2 management and debugging
 # Copyright (C) 2002, 2005 Oracle.  All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify

Modified: trunk/ocfs2console/format.py
===================================================================
--- trunk/ocfs2console/format.py	2005-01-26 01:33:38 UTC (rev 579)
+++ trunk/ocfs2console/format.py	2005-01-26 02:05:08 UTC (rev 580)
@@ -1,4 +1,4 @@
-# OCFS2Tool - GUI frontend for OCFS2 management and debugging
+# OCFS2Console - GUI frontend for OCFS2 management and debugging
 # Copyright (C) 2002, 2005 Oracle.  All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify

Modified: trunk/ocfs2console/general.py
===================================================================
--- trunk/ocfs2console/general.py	2005-01-26 01:33:38 UTC (rev 579)
+++ trunk/ocfs2console/general.py	2005-01-26 02:05:08 UTC (rev 580)
@@ -1,4 +1,4 @@
-# OCFS2Tool - GUI frontend for OCFS2 management and debugging
+# OCFS2Console - GUI frontend for OCFS2 management and debugging
 # Copyright (C) 2002, 2005 Oracle.  All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify

Modified: trunk/ocfs2console/guiutil.py
===================================================================
--- trunk/ocfs2console/guiutil.py	2005-01-26 01:33:38 UTC (rev 579)
+++ trunk/ocfs2console/guiutil.py	2005-01-26 02:05:08 UTC (rev 580)
@@ -1,4 +1,4 @@
-# OCFS2Tool - GUI frontend for OCFS2 management and debugging
+# OCFS2Console - GUI frontend for OCFS2 management and debugging
 # Copyright (C) 2002, 2005 Oracle.  All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify

Modified: trunk/ocfs2console/interface.py
===================================================================
--- trunk/ocfs2console/menu.py	2005-01-26 01:33:38 UTC (rev 579)
+++ trunk/ocfs2console/menu.py	2005-01-26 02:05:08 UTC (rev 580)
@@ -1,4 +1,4 @@
-# OCFS2Tool - GUI frontend for OCFS2 management and debugging
+# OCFS2Console - GUI frontend for OCFS2 management and debugging
 # Copyright (C) 2002, 2005 Oracle.  All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify

Modified: trunk/ocfs2console/nodemap.py
===================================================================
--- trunk/ocfs2console/nodemap.py	2005-01-26 01:33:38 UTC (rev 579)
+++ trunk/ocfs2console/nodemap.py	2005-01-26 02:05:08 UTC (rev 580)
@@ -1,4 +1,4 @@
-# OCFS2Tool - GUI frontend for OCFS2 management and debugging
+# OCFS2Console - GUI frontend for OCFS2 management and debugging
 # Copyright (C) 2002, 2005 Oracle.  All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify

Modified: trunk/ocfs2console/ocfs2console.8.in
===================================================================
--- trunk/ocfs2console/ocfs2console.8.in	2005-01-26 01:33:38 UTC (rev 579)
+++ trunk/ocfs2console/ocfs2console.8.in	2005-01-26 02:05:08 UTC (rev 580)
@@ -1,12 +1,12 @@
-.TH OCFSTOOL 1 "August 2002" "Version @VERSION@" "OCFS Manual Pages"
+.TH OCFS2CONSOLE 1 "January 2005" "Version @VERSION@" "OCFS2 Manual Pages"
 .SH NAME
-ocfstool - GUI frontend for OCFS management and debugging
+ocfs2console - GUI frontend for OCFS2 management and debugging
 .SH SYNOPSIS
-.B ocfstool
+.B ocfs2console
 
 .SH DESCRIPTION
 .PP
-\fBocfstool\fP is a GUI frontend for managing and debugging OCFS volumes on
+\fBocfs2console\fP is a GUI frontend for managing and debugging OCFS2 volumes on
 the system. One can mount and unmount volumes, format, view overview
 information and individual files, see the current node map, and block
 bitmap.
@@ -15,10 +15,10 @@
 Stuff.
 
 .SH SEE ALSO
-.BR ocfs(5)
+.BR ocfs2(5)
 
 .SH AUTHORS
 Oracle Corporation
 
 .SH COPYRIGHT
-Copyright \(co 2002, 2004 Oracle Corporation
+Copyright \(co 2002, 2005 Oracle Corporation

Modified: trunk/ocfs2console/process.py
===================================================================
--- trunk/ocfs2console/process.py	2005-01-26 01:33:38 UTC (rev 579)
+++ trunk/ocfs2console/process.py	2005-01-26 02:05:08 UTC (rev 580)
@@ -1,4 +1,4 @@
-# OCFS2Tool - GUI frontend for OCFS2 management and debugging
+# OCFS2Console - GUI frontend for OCFS2 management and debugging
 # Copyright (C) 2002, 2005 Oracle.  All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify

Modified: trunk/ocfs2console/toolbar.py
===================================================================
--- trunk/ocfs2console/toolbar.py	2005-01-26 01:33:38 UTC (rev 579)
+++ trunk/ocfs2console/toolbar.py	2005-01-26 02:05:08 UTC (rev 580)
@@ -1,4 +1,4 @@
-# OCFS2Tool - GUI frontend for OCFS2 management and debugging
+# OCFS2Console - GUI frontend for OCFS2 management and debugging
 # Copyright (C) 2005 Oracle.  All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify



More information about the Ocfs2-tools-commits mailing list
--- trunk/ocfs2console/about.py	2005-01-26 01:33:38 UTC (rev 579)
+++ trunk/ocfs2console/about.py	2005-01-26 02:05:08 UTC (rev 580)
@@ -1,4 +1,4 @@
 # OCFS2Tool - GUI frontend for OCFS2 management and debugging
 # Copyright (C) 2002, 2005 Oracle.  All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
@@ -18,7 +18,7 @@
 OCFS2TOOL_VERSION = '0.0.2'
 
 def print_version():
-    print 'OCFS2Tool version %s' % OCFS2TOOL_VERSION
+    print 'OCFS2Console version %s' % OCFS2TOOL_VERSION
 
 def print_usage(name):
     print '''Usage: %s [OPTION]...
@@ -73,7 +73,7 @@
         dialog.set_transient_for(pv.toplevel)
         dialog.set_destroy_with_parent(True)
 
-        set_props(dialog, name='OCFS2 Tool',
+        set_props(dialog, name='OCFS2 Console',
                           version=OCFS2TOOL_VERSION,
                           copyright=copyright,
                           license=license,
@@ -86,7 +86,7 @@
                                    flags=gtk.DIALOG_DESTROY_WITH_PARENT,
                                    buttons=gtk.BUTTONS_CLOSE)
         dialog.label.set_text(
-'''OCFS2 Tool
+'''OCFS2 Console 
 Version %s
 Copyright (C) 2002, 2005 Oracle.
 All Rights Reserved.''' % OCFS2TOOL_VERSION)
@@ -1,4 +1,4 @@
-# OCFS2Tool - GUI frontend for OCFS2 management and debugging
+# OCFS2Console - GUI frontend for OCFS2 management and debugging
 # Copyright (C) 2002, 2005 Oracle.  All rights reserved.
 #

Modified: trunk/ocfs2console/browser.py
===================================================================
--- trunk/ocfs2console/interface.py	2005-01-26 01:33:38 UTC (rev 579)
+++ trunk/ocfs2console/interface.py	2005-01-26 02:05:08 UTC (rev 580)
@@ -1,4 +1,4 @@
 # OCFS2Tool - GUI frontend for OCFS2 management and debugging
 # Copyright (C) 2002, 2005 Oracle.  All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
@@ -211,7 +211,7 @@
 
 def create_window():
     window = gtk.Window()
-    set_props(window, title='OCFS2 Tool',
+    set_props(window, title='OCFS2 Console',
                       default_width=520,
                       default_height=420,
                       border_width=0)
@@ -1,4 +1,4 @@
-# OCFS2Tool - GUI frontend for OCFS2 management and debugging
+# OCFS2Console - GUI frontend for OCFS2 management and debugging
 # Copyright (C) 2002, 2005 Oracle.  All rights reserved.
 #

Modified: trunk/ocfs2console/menu.py
===================================================================